@@ -43,13 +43,14 @@ extern "C"
 /**
  * Initialise the oSIP parser.
  */
-  int parser_init ();
+  int parser_init (void);
 
 /**
  * Fix the via header for INCOMING requests only.
  * a copy of ip_addr is done.
  */
-  int osip_message_fix_last_via_header (osip_message_t * request, const char *ip_addr, int port);
+  int osip_message_fix_last_via_header (osip_message_t * request,
+					const char *ip_addr, int port);
 
 
 /**
@@ -58,13 +59,11 @@ extern "C"
  * the osip_message_t element since last call of osip_message_to_str() you
  * can call osip_message_force_update() to force a rebuild.
 */
-#ifdef USE_TMP_BUFFER
 /**
  * Check if the element is already built. (so osip_message_to_str won't build it again)
  * @param sip The element to check.
 */
   int osip_message_get__property (const osip_message_t * sip);
-#endif
 
 /**
  * Force a osip_message_t element to be rebuild on next osip_message_to_str() call.
@@ -90,13 +89,15 @@ extern "C"
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_accept (const osip_message_t * sip, int pos, osip_accept_t ** dest);
+  int osip_message_get_accept (const osip_message_t * sip, int pos,
+			       osip_accept_t ** dest);
 /**
  * Set the Accept-encoding header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_accept_encoding (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_accept_encoding (osip_message_t * sip,
+					const char *hvalue);
 /**
  * Get one Accept-encoding header.
  * @param sip The element to work on.
@@ -104,13 +105,14 @@ extern "C"
  * @param dest A pointer on the header found.
  */
   int osip_message_get_accept_encoding (const osip_message_t * sip, int pos,
-			      osip_accept_encoding_t ** dest);
+					osip_accept_encoding_t ** dest);
 /**
  * Set the Accept-language header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_accept_language (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_accept_language (osip_message_t * sip,
+					const char *hvalue);
 /**
  * Get one Accept header.
  * @param sip The element to work on.
@@ -118,7 +120,7 @@ extern "C"
  * @param dest A pointer on the header found.
  */
   int osip_message_get_accept_language (const osip_message_t * sip, int pos,
-			      osip_accept_language_t ** dest);
+					osip_accept_language_t ** dest);
 /**
  * Set the Alert-info header.
  * @param sip The element to work on.
@@ -132,7 +134,7 @@ extern "C"
  * @param dest A pointer on the header found.
  */
   int osip_message_get_alert_info (const osip_message_t * sip, int pos,
-			 osip_alert_info_t ** dest);
+				   osip_alert_info_t ** dest);
 /**
  * Set the Allow header.
  * @param sip The element to work on.
@@ -145,13 +147,15 @@ extern "C"
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_allow (const osip_message_t * sip, int pos, osip_allow_t ** dest);
+  int osip_message_get_allow (const osip_message_t * sip, int pos,
+			      osip_allow_t ** dest);
 /**
  * Set the Authorization header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_authorization (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_authorization (osip_message_t * sip,
+				      const char *hvalue);
 /**
  * Get one Authorization header.
  * @param sip The element to work on.
@@ -159,7 +163,7 @@ extern "C"
  * @param dest A pointer on the header found.
  */
   int osip_message_get_authorization (const osip_message_t * sip, int pos,
-			    osip_authorization_t ** dest);
+				      osip_authorization_t ** dest);
 /**
  * Set the Call-id header.
  * @param sip The element to work on.
@@ -183,7 +187,8 @@ extern "C"
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_call_info (const osip_message_t * sip, int pos, osip_call_info_t ** dest);
+  int osip_message_get_call_info (const osip_message_t * sip, int pos,
+				  osip_call_info_t ** dest);
 /**
  * Set the Contact header.
  * @param sip The element to work on.
@@ -196,27 +201,32 @@ extern "C"
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_contact (const osip_message_t * sip, int pos, osip_contact_t ** dest);
+  int osip_message_get_contact (const osip_message_t * sip, int pos,
+				osip_contact_t ** dest);
 /**
  * Set the Content-disposition header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_content_disposition (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_content_disposition (osip_message_t * sip,
+					    const char *hvalue);
 /**
  * Get one Content-disposition header.
  * @param sip The element to work on.
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_content_disposition (const osip_message_t * sip, int pos,
-				  osip_content_disposition_t ** dest);
+  int osip_message_get_content_disposition (const osip_message_t * sip,
+					    int pos,
+					    osip_content_disposition_t **
+					    dest);
 /**
  * Set the Content-encoding header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_content_encoding (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_content_encoding (osip_message_t * sip,
+					 const char *hvalue);
 /**
  * Get one Content-encoding header.
  * @param sip The element to work on.
@@ -224,29 +234,33 @@ extern "C"
  * @param dest A pointer on the header found.
  */
   int osip_message_get_content_encoding (const osip_message_t * sip, int pos,
-			       osip_content_encoding_t ** dest);
+					 osip_content_encoding_t ** dest);
 /**
  * Set the Content-length header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_content_length (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_content_length (osip_message_t * sip,
+				       const char *hvalue);
 /**
  * Get one Content-length header.
  * @param sip The element to work on.
  */
-  osip_content_length_t *osip_message_get_content_length (const osip_message_t * sip);
+  osip_content_length_t *osip_message_get_content_length (const osip_message_t
+							  * sip);
 /**
  * Set the Content-type header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_content_type (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_content_type (osip_message_t * sip,
+				     const char *hvalue);
 /**
  * Get one Content-type header.
  * @param sip The element to work on.
  */
-  osip_content_type_t *osip_message_get_content_type (const osip_message_t * sip);
+  osip_content_type_t *osip_message_get_content_type (const osip_message_t *
+						      sip);
 /**
  * Set the Cseq header.
  * @param sip The element to work on.
@@ -271,7 +285,7 @@ extern "C"
  * @param dest A pointer on the header found.
  */
   int osip_message_get_error_info (const osip_message_t * sip, int pos,
-			 osip_error_info_t ** dest);
+				   osip_error_info_t ** dest);
 /**
  * Set the From header.
  * @param sip The element to work on.
@@ -288,53 +302,62 @@ extern "C"
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_mime_version (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_mime_version (osip_message_t * sip,
+				     const char *hvalue);
 /**
  * Get the Mime-version header.
  * @param sip The element to work on.
  */
-  osip_mime_version_t *osip_message_get_mime_version (const osip_message_t * sip);
+  osip_mime_version_t *osip_message_get_mime_version (const osip_message_t *
+						      sip);
 /**
  * Set the Proxy-authenticate header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_proxy_authenticate (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_proxy_authenticate (osip_message_t * sip,
+					   const char *hvalue);
 /**
  * Get the Proxy-authenticate header.
  * @param sip The element to work on.
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_proxy_authenticate (const osip_message_t * sip, int pos,
-				 osip_proxy_authenticate_t ** dest);
+  int osip_message_get_proxy_authenticate (const osip_message_t * sip,
+					   int pos,
+					   osip_proxy_authenticate_t ** dest);
 /**
  * Set the Proxy-authorization header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_proxy_authorization (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_proxy_authorization (osip_message_t * sip,
+					    const char *hvalue);
 /**
  * Get one Proxy-authorization header.
  * @param sip The element to work on.
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_proxy_authorization (const osip_message_t * sip, int pos,
-				  osip_proxy_authorization_t ** dest);
+  int osip_message_get_proxy_authorization (const osip_message_t * sip,
+					    int pos,
+					    osip_proxy_authorization_t **
+					    dest);
 /**
  * Set the Record-Route header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_record_route (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_record_route (osip_message_t * sip,
+				     const char *hvalue);
 /**
  * Get one Record-route header.
  * @param sip The element to work on.
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_record_route (const osip_message_t * sip, int pos, osip_record_route_t ** dest);
+  int osip_message_get_record_route (const osip_message_t * sip, int pos,
+				     osip_record_route_t ** dest);
 /**
  * Set the Route header.
  * @param sip The element to work on.
@@ -347,7 +370,8 @@ extern "C"
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_route (const osip_message_t * sip, int pos, osip_route_t ** dest);
+  int osip_message_get_route (const osip_message_t * sip, int pos,
+			      osip_route_t ** dest);
 /**
  * Set the To header.
  * @param sip The element to work on.
@@ -365,19 +389,27 @@ extern "C"
  * @param hvalue The string describing the element.
  */
   int osip_message_set_via (osip_message_t * sip, const char *hvalue);
+/**
+ * Append a Via header.
+ * @param sip The element to work on.
+ * @param hvalue The string describing the element.
+ */
+  int osip_message_append_via (osip_message_t * sip, const char *hvalue);
 /**
  * Get one Via header.
  * @param sip The element to work on.
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_via (const osip_message_t * sip, int pos, osip_via_t ** dest);
+  int osip_message_get_via (const osip_message_t * sip, int pos,
+			    osip_via_t ** dest);
 /**
  * Set the Www-authenticate header.
  * @param sip The element to work on.
  * @param hvalue The string describing the element.
  */
-  int osip_message_set_www_authenticate (osip_message_t * sip, const char *hvalue);
+  int osip_message_set_www_authenticate (osip_message_t * sip,
+					 const char *hvalue);
 /**
  * Get one Www-authenticate header.
  * @param sip The element to work on.
@@ -385,7 +417,7 @@ extern "C"
  * @param dest A pointer on the header found.
  */
   int osip_message_get_www_authenticate (const osip_message_t * sip, int pos,
-			       osip_www_authenticate_t ** dest);
+					 osip_www_authenticate_t ** dest);
 /**
  * Allocate and Add an "unknown" header (not defined in oSIP).
  * @param sip The element to work on.
@@ -393,7 +425,7 @@ extern "C"
  * @param hvalue The token value.
  */
   int osip_message_set_header (osip_message_t * sip, const char *hname,
-		     const char *hvalue);
+			       const char *hvalue);
 /**
  * Allocate and Add an "unknown" header (not defined in oSIP).
  * The element is add on the top of the unknown header list. 
@@ -402,7 +434,7 @@ extern "C"
  * @param hvalue The token value.
  */
   int osip_message_set_topheader (osip_message_t * sip, const char *hname,
-			const char *hvalue);
+				  const char *hvalue);
 
 /**
  * Find an "unknown" header. (not defined in oSIP)
@@ -411,15 +443,17 @@ extern "C"
  * @param pos The index where to start searching for the header.
  * @param dest A pointer to the header found.
  */
-  int osip_message_header_get_byname (const osip_message_t * sip, const char *hname, int pos,
-			    osip_header_t ** dest);
+  int osip_message_header_get_byname (const osip_message_t * sip,
+				      const char *hname, int pos,
+				      osip_header_t ** dest);
 /**
  * Get one "unknown" header.
  * @param sip The element to work on.
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_header (const osip_message_t * sip, int pos, osip_header_t ** dest);
+  int osip_message_get_header (const osip_message_t * sip, int pos,
+			       osip_header_t ** dest);
 
 /**
  * Set the Body of the SIP message.
@@ -439,7 +473,8 @@ extern "C"
  * @param pos The index of the element to get.
  * @param dest A pointer on the body found.
  */
-  int osip_message_get_body (const osip_message_t * sip, int pos, osip_body_t ** dest);
+  int osip_message_get_body (const osip_message_t * sip, int pos,
+			     osip_body_t ** dest);
 
 
 
@@ -449,8 +484,8 @@ extern "C"
   void msg_logrequest (osip_message_t * sip, char *fmt);
   void msg_logresponse (osip_message_t * sip, char *fmt);
 #else
-  #define msg_logrequest(P,Q) ;
-  #define msg_logresponse(P,Q) ;
+#define msg_logrequest(P,Q) ;
+#define msg_logresponse(P,Q) ;
 #endif
 #endif
 
