@@ -77,13 +77,15 @@ extern "C"
  * @param name The token name.
  * @param value The token value.
  */
-  int osip_uri_param_set (osip_uri_param_t * url_param, char *name, char *value);
+  int osip_uri_param_set (osip_uri_param_t * url_param, char *name,
+			  char *value);
 /**
  * Clone a url parameter element.
  * @param url_param The element to work on.
  * @param dest The resulting new allocated element.
  */
-  int osip_uri_param_clone (const osip_uri_param_t * url_param, osip_uri_param_t ** dest);
+  int osip_uri_param_clone (const osip_uri_param_t * url_param,
+			    osip_uri_param_t ** dest);
 #ifndef DOXYGEN
 /*
  * Free a list of a url parameter element.
@@ -105,7 +107,7 @@ extern "C"
  * @param dest A pointer on the element found.
  */
   int osip_uri_param_get_byname (osip_list_t * url_params, char *name,
-			   osip_uri_param_t ** dest);
+				 osip_uri_param_t ** dest);
 
 /**
  * Allocate a generic parameter element.
@@ -412,7 +414,8 @@ extern "C"
   char *next_separator (const char *ch, int separator_osip_to_find,
 			int before_separator);
 
-  char *__osip_uri_escape_nonascii_and_nondef (const char *string, const char *def);
+  char *__osip_uri_escape_nonascii_and_nondef (const char *string,
+					       const char *def);
   char *__osip_uri_escape_userinfo (const char *string);
   char *__osip_uri_escape_password (const char *string);
   char *__osip_uri_escape_uri_param (char *string);
