@@ -23,12 +23,14 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 #include "parser.h"
 
 int
 osip_authorization_init (osip_authorization_t ** dest)
 {
-  *dest = (osip_authorization_t *) osip_malloc (sizeof (osip_authorization_t));
+  *dest =
+    (osip_authorization_t *) osip_malloc (sizeof (osip_authorization_t));
   if (*dest == NULL)
     return -1;
   (*dest)->auth_type = NULL;
@@ -57,7 +59,7 @@ osip_message_set_authorization (osip_message_t * sip, const char *hvalue)
   osip_authorization_t *authorization;
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   if (sip == NULL || sip->authorizations == NULL)
@@ -71,9 +73,7 @@ osip_message_set_authorization (osip_message_t * sip, const char *hvalue)
       osip_authorization_free (authorization);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->authorizations, authorization, -1);
   return 0;
 }
@@ -105,7 +105,8 @@ osip_authorization_parse (osip_authorization_t * auth, const char *hvalue)
     {
       int parse_ok = 0;
 
-      if (__osip_quoted_string_set ("username", space, &(auth->username), &next))
+      if (__osip_quoted_string_set
+	  ("username", space, &(auth->username), &next))
 	return -1;
       if (next == NULL)
 	return 0;		/* end of header detected! */
@@ -141,7 +142,8 @@ osip_authorization_parse (osip_authorization_t * auth, const char *hvalue)
 	  space = next;
 	  parse_ok++;
 	}
-      if (__osip_quoted_string_set ("response", space, &(auth->response), &next))
+      if (__osip_quoted_string_set
+	  ("response", space, &(auth->response), &next))
 	return -1;
       if (next == NULL)
 	return 0;		/* end of header detected! */
@@ -247,14 +249,15 @@ osip_authorization_parse (osip_authorization_t * auth, const char *hvalue)
 /* returns null on error. */
 int
 osip_message_get_authorization (const osip_message_t * sip, int pos,
-		      osip_authorization_t ** dest)
+				osip_authorization_t ** dest)
 {
   osip_authorization_t *authorization;
 
   *dest = NULL;
   if (osip_list_size (sip->authorizations) <= pos)
     return -1;			/* does not exist */
-  authorization = (osip_authorization_t *) osip_list_get (sip->authorizations, pos);
+  authorization =
+    (osip_authorization_t *) osip_list_get (sip->authorizations, pos);
   *dest = authorization;
   return pos;
 }
@@ -266,7 +269,8 @@ osip_authorization_get_auth_type (const osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_auth_type (osip_authorization_t * authorization, char *auth_type)
+osip_authorization_set_auth_type (osip_authorization_t * authorization,
+				  char *auth_type)
 {
   authorization->auth_type = (char *) auth_type;
 }
@@ -278,7 +282,8 @@ osip_authorization_get_username (osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_username (osip_authorization_t * authorization, char *username)
+osip_authorization_set_username (osip_authorization_t * authorization,
+				 char *username)
 {
   authorization->username = (char *) username;
 }
@@ -290,7 +295,8 @@ osip_authorization_get_realm (osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_realm (osip_authorization_t * authorization, char *realm)
+osip_authorization_set_realm (osip_authorization_t * authorization,
+			      char *realm)
 {
   authorization->realm = (char *) realm;
 }
@@ -302,7 +308,8 @@ osip_authorization_get_nonce (osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_nonce (osip_authorization_t * authorization, char *nonce)
+osip_authorization_set_nonce (osip_authorization_t * authorization,
+			      char *nonce)
 {
   authorization->nonce = (char *) nonce;
 }
@@ -326,7 +333,8 @@ osip_authorization_get_response (osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_response (osip_authorization_t * authorization, char *response)
+osip_authorization_set_response (osip_authorization_t * authorization,
+				 char *response)
 {
   authorization->response = (char *) response;
 }
@@ -338,7 +346,8 @@ osip_authorization_get_digest (osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_digest (osip_authorization_t * authorization, char *digest)
+osip_authorization_set_digest (osip_authorization_t * authorization,
+			       char *digest)
 {
   authorization->digest = (char *) digest;
 }
@@ -350,7 +359,8 @@ osip_authorization_get_algorithm (osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_algorithm (osip_authorization_t * authorization, char *algorithm)
+osip_authorization_set_algorithm (osip_authorization_t * authorization,
+				  char *algorithm)
 {
   authorization->algorithm = (char *) algorithm;
 }
@@ -362,7 +372,8 @@ osip_authorization_get_cnonce (osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_cnonce (osip_authorization_t * authorization, char *cnonce)
+osip_authorization_set_cnonce (osip_authorization_t * authorization,
+			       char *cnonce)
 {
   authorization->cnonce = (char *) cnonce;
 }
@@ -374,7 +385,8 @@ osip_authorization_get_opaque (osip_authorization_t * authorization)
 }
 
 void
-osip_authorization_set_opaque (osip_authorization_t * authorization, char *opaque)
+osip_authorization_set_opaque (osip_authorization_t * authorization,
+			       char *opaque)
 {
   authorization->opaque = (char *) opaque;
 }
@@ -387,7 +399,7 @@ osip_authorization_get_message_qop (osip_authorization_t * authorization)
 
 void
 osip_authorization_set_message_qop (osip_authorization_t * authorization,
-			      char *message_qop)
+				    char *message_qop)
 {
   authorization->message_qop = (char *) message_qop;
 }
@@ -400,7 +412,7 @@ osip_authorization_get_nonce_count (osip_authorization_t * authorization)
 
 void
 osip_authorization_set_nonce_count (osip_authorization_t * authorization,
-			      char *nonce_count)
+				    char *nonce_count)
 {
   authorization->nonce_count = (char *) nonce_count;
 }
@@ -412,7 +424,7 @@ osip_authorization_set_nonce_count (osip_authorization_t * authorization,
 int
 osip_authorization_to_str (const osip_authorization_t * auth, char **dest)
 {
-  int len;
+  size_t len;
   char *tmp;
 
   *dest = NULL;
@@ -566,7 +578,8 @@ osip_authorization_free (osip_authorization_t * authorization)
 }
 
 int
-osip_authorization_clone (const osip_authorization_t * auth, osip_authorization_t ** dest)
+osip_authorization_clone (const osip_authorization_t * auth,
+			  osip_authorization_t ** dest)
 {
   int i;
   osip_authorization_t *au;
