@@ -22,6 +22,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 #include "parser.h"
 
 /* content-Encoding = token
@@ -33,7 +34,7 @@ osip_message_set_content_encoding (osip_message_t * sip, const char *hvalue)
   osip_content_encoding_t *content_encoding;
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   i = osip_content_encoding_init (&content_encoding);
@@ -45,23 +46,22 @@ osip_message_set_content_encoding (osip_message_t * sip, const char *hvalue)
       osip_content_encoding_free (content_encoding);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->content_encodings, content_encoding, -1);
   return 0;
 }
 
 int
 osip_message_get_content_encoding (const osip_message_t * sip, int pos,
-			 osip_content_encoding_t ** dest)
+				   osip_content_encoding_t ** dest)
 {
   osip_content_encoding_t *ce;
 
   *dest = NULL;
   if (osip_list_size (sip->content_encodings) <= pos)
     return -1;			/* does not exist */
-  ce = (osip_content_encoding_t *) osip_list_get (sip->content_encodings, pos);
+  ce =
+    (osip_content_encoding_t *) osip_list_get (sip->content_encodings, pos);
   *dest = ce;
   return pos;
 }
