@@ -34,6 +34,10 @@ static int msg_headers_parse (osip_message_t * sip,
 static int msg_osip_body_parse (osip_message_t * sip,
 				const char *start_of_buf,
 				const char **next_body);
+static int msg_osip_body_parse2 (osip_message_t * sip,
+				 const char *start_of_buf,
+				 const char **next_body,
+				 size_t length);
 
 
 static int
@@ -75,7 +79,12 @@ __osip_message_startline_parsereq (osip_message_t * dest, const char *buf,
       return -1;
     }
   if (p1 - p2 < 2)
-    return -1;
+    {
+      osip_free(dest->sip_method);
+      dest->sip_method = NULL;
+      return -1;
+    }
+
   requesturi = (char *) osip_malloc (p1 - p2);
   osip_strncpy (requesturi, p2 + 1, (p1 - p2 - 1));
   osip_clrspace (requesturi);
@@ -83,8 +92,14 @@ __osip_message_startline_parsereq (osip_message_t * dest, const char *buf,
   osip_uri_init (&(dest->req_uri));
   i = osip_uri_parse (dest->req_uri, requesturi);
   osip_free (requesturi);
-  if (i == -1)
-    return -1;
+  if (i != 0)
+    {
+      osip_free(dest->sip_method);
+      dest->sip_method = NULL;
+      osip_uri_free(dest->req_uri);
+      dest->req_uri = NULL;
+      return -1;
+    }
 
   /* find the the version and the beginning of headers */
   {
@@ -99,14 +114,33 @@ __osip_message_startline_parsereq (osip_message_t * dest, const char *buf,
 	    OSIP_TRACE (osip_trace
 			(__FILE__, __LINE__, OSIP_ERROR, NULL,
 			 "No crlf found\n"));
+ 	    osip_free(dest->sip_method);
+ 	    dest->sip_method = NULL;
+ 	    osip_uri_free(dest->req_uri);
+ 	    dest->req_uri = NULL;
 	    return -1;
 	  }
       }
     if (hp - p1 < 2)
-      return -1;
+      {
+ 	osip_free(dest->sip_method);
+ 	dest->sip_method = NULL;
+ 	osip_uri_free(dest->req_uri);
+ 	dest->req_uri = NULL;
+ 	return -1;
+      }
+ 
+
     dest->sip_version = (char *) osip_malloc (hp - p1);
     osip_strncpy (dest->sip_version, p1 + 1, (hp - p1 - 1));
 
+    if (0!=osip_strcasecmp(dest->sip_version, "SIP/2.0"))
+      {
+ 	OSIP_TRACE (osip_trace
+ 		    (__FILE__, __LINE__, OSIP_ERROR, NULL,
+ 		     "Wrong version number\n"));
+      }
+
     hp++;
     if ((*hp) && ('\r' == hp[-1]) && ('\n' == hp[0]))
       hp++;
@@ -221,8 +255,8 @@ osip_util_replace_all_lws (char *sip_message)
 	  || ('\0' == tmp[1]) || ('\0' == tmp[2]) || ('\0' == tmp[3]))
 	return;
 
-      if ((('\r' == tmp[0]) && ('\r' == tmp[1])
-	   && ('\r' == tmp[2]) && ('\r' == tmp[3]))
+      if ((('\r' == tmp[0]) && ('\n' == tmp[1])
+	   && ('\r' == tmp[2]) && ('\n' == tmp[3]))
 	  ||
 	  (('\r' == tmp[0]) && ('\r' == tmp[1]))
 	  || (('\n' == tmp[0]) && ('\n' == tmp[1])))
@@ -408,6 +442,7 @@ msg_handle_multiple_values (osip_message_t * sip, char *hname, char *hvalue)
       || strncmp (hname, "call-id", 7) == 0 || (strncmp (hname, "cseq", 4) == 0 && strlen (hname) == 4)	/* AMD: BUG fix */
       || strncmp (hname, "subject", 7) == 0 || strncmp (hname, "user-agent", 10) == 0 || strncmp (hname, "server", 6) == 0 || strncmp (hname, "www-authenticate", 16) == 0	/* AMD: BUG fix */
       || strncmp (hname, "authentication-info", 19) == 0 || strncmp (hname, "proxy-authenticate", 20) == 0 || strncmp (hname, "proxy-authorization", 19) == 0 || strncmp (hname, "proxy-authentication-info", 25) == 0	/* AMD: BUG fix */
+      || strncmp (hname, "expires", 7) == 0
       || strncmp (hname, "authorization", 13) == 0)
     /* there is no multiple header! likely      */
     /* to happen most of the time...            */
@@ -597,6 +632,153 @@ msg_headers_parse (osip_message_t * sip, const char *start_of_header,
   return -1;
 }
 
+static int
+msg_osip_body_parse2 (osip_message_t * sip, const char *start_of_buf,
+		      const char **next_body, size_t length)
+{
+  const char *start_of_body;
+  const char *end_of_body;
+  char *tmp;
+  int i;
+
+  char *sep_boundary;
+  osip_generic_param_t *ct_param;
+
+  if (sip->content_type == NULL
+      ||sip->content_type->type==NULL
+      ||sip->content_type->subtype==NULL)
+    return 0;		/* no body is attached */
+  
+  if (0!=osip_strcasecmp(sip->content_type->type, "multipart"))
+    {
+      size_t osip_body_len;
+      
+      if (start_of_buf[0] == '\0')
+	return -1;		/* final CRLF is missing */
+      /* get rid of the first CRLF */
+      if ('\r' == start_of_buf[0])
+	{
+	  if ('\n' == start_of_buf[1])
+	    start_of_body = start_of_buf + 2;
+	  else
+	    start_of_body = start_of_buf + 1;
+	}
+      else if ('\n' == start_of_buf[0])
+	start_of_body = start_of_buf + 1;
+      else
+	return -1;	/* message does not end with CRLFCRLF, CRCR or LFLF */
+      
+      /* update length (without CRLFCRLF */
+      length = length-(start_of_buf-start_of_body);
+      if (length<=2)
+	return -1;
+      
+      if (sip->content_length != NULL)
+	osip_body_len = osip_atoi (sip->content_length->value);
+      else
+	{
+	  /* if content_length does not exist, set it. */
+	  char tmp[16];
+	  
+	  /* case where content-length is missing but the
+		 body only contains non-binary data */
+	  if (0==osip_strcasecmp(sip->content_type->type, "application")
+	      && 0==osip_strcasecmp(sip->content_type->subtype,"sdp"))
+	    {
+	      osip_body_len = strlen (start_of_body);
+	      sprintf (tmp, "%i", osip_body_len);
+	      i = osip_message_set_content_length (sip, tmp);
+	      if (i != 0)
+		return -1;
+	    }
+	  else return -1; /* Content-type may be non binary data */
+	}
+      
+      if (length<osip_body_len)
+	{
+	  OSIP_TRACE (osip_trace
+		      (__FILE__, __LINE__, OSIP_ERROR, NULL,
+		       "Message was not receieved enterely. lenngth=%i osip_body_len=%i\n",length, osip_body_len));
+	  return -1;
+	}
+
+      end_of_body = start_of_body + osip_body_len;
+      tmp = osip_malloc (end_of_body - start_of_body + 2);
+      if (tmp == NULL)
+	return -1;
+      memcpy (tmp, start_of_body, end_of_body - start_of_body);
+      
+      i = osip_message_set_body (sip, tmp);
+      osip_free (tmp);
+      if (i != 0)
+	return -1;
+      return 0;
+    }
+
+  /* find the boundary */
+  i = osip_generic_param_get_byname (sip->content_type->gen_params,
+				     "boundary", &ct_param);
+  if (i != 0)
+    return -1;
+
+  if (ct_param == NULL)
+    return -1;
+  if (ct_param->gvalue == NULL)
+    return -1;			/* No boundary but multiple headers??? */
+
+  sep_boundary = (char *) osip_malloc (strlen (ct_param->gvalue) + 3);
+  sprintf (sep_boundary, "--%s", ct_param->gvalue);
+
+  *next_body = NULL;
+  start_of_body = start_of_buf;
+  for (;;)
+    {
+      i =
+	__osip_find_next_occurence (sep_boundary, start_of_body,
+				    &start_of_body);
+      if (i == -1)
+	{
+	  osip_free (sep_boundary);
+	  return -1;
+	}
+      i =
+	__osip_find_next_occurence (sep_boundary,
+				    start_of_body + strlen (sep_boundary),
+				    &end_of_body);
+      if (i == -1)
+	{
+	  osip_free (sep_boundary);
+	  return -1;
+	}
+
+      /* this is the real beginning of body */
+      start_of_body = start_of_body + strlen (sep_boundary) + 2;
+
+      tmp = osip_malloc (end_of_body - start_of_body + 1);
+      memcpy (tmp, start_of_body, end_of_body - start_of_body);
+      tmp[end_of_body - start_of_body]='\0';
+
+      i = osip_message_set_body_mime (sip, tmp);
+      osip_free (tmp);
+      if (i == -1)
+	{
+	  osip_free (sep_boundary);
+	  return -1;
+	}
+
+      if (strncmp (end_of_body + strlen (sep_boundary), "--", 2) == 0)
+	{			/* end of all bodies */
+	  *next_body = end_of_body;
+	  osip_free (sep_boundary);
+	  return 0;
+	}
+      /* continue on the next body */
+      start_of_body = end_of_body;
+    }
+  /* Unreachable code */
+  /* osip_free (sep_boundary); */
+  return -1;
+}
 
 /* internal method to parse the body */
 static int
@@ -611,64 +793,59 @@ msg_osip_body_parse (osip_message_t * sip, const char *start_of_buf,
   char *sep_boundary;
   osip_generic_param_t *ct_param;
 
-  /* if MIME-Version: does not exist we just have */
-  /* to deal with one body and no header... */
-  if (sip->mime_version == NULL)
-    {				/* Mime-Version header does NOT exist */
-      if (sip->content_type == NULL)
-	return 0;		/* no body is attached */
-      else
+  if (sip->content_type == NULL
+      ||sip->content_type->type==NULL
+      ||sip->content_type->subtype==NULL)
+    return 0;		/* no body is attached */
+  
+  if (0!=osip_strcasecmp(sip->content_type->type, "multipart"))
+    {
+      size_t osip_body_len;
+      
+      if (start_of_buf[0] == '\0')
+	return -1;		/* final CRLF is missing */
+      /* get rid of the first CRLF */
+      if ('\r' == start_of_buf[0])
 	{
-	  size_t osip_body_len;
-
-	  if (start_of_buf[0] == '\0')
-	    return -1;		/* final CRLF is missing */
-	  /* get rid of the first CRLF */
-	  if ('\r' == start_of_buf[0])
-	    {
-	      if ('\n' == start_of_buf[1])
-		start_of_body = start_of_buf + 2;
-	      else
-		start_of_body = start_of_buf + 1;
-	    }
-	  else if ('\n' == start_of_buf[0])
+	  if ('\n' == start_of_buf[1])
+	    start_of_body = start_of_buf + 2;
+	  else
 	    start_of_body = start_of_buf + 1;
-	  else
-	    return -1;		/* message does not end with CRLFCRLF, CRCR or LFLF */
-
-	  if (sip->content_length != NULL)
-	    osip_body_len = osip_atoi (sip->content_length->value);
-	  else
-	    {			/* if content_length does not exist, set it. */
-	      char tmp[16];
-
-	      osip_body_len = strlen (start_of_body);
-	      sprintf (tmp, "%i", osip_body_len);
-	      i = osip_message_set_content_length (sip, tmp);
-	      if (i != 0)
-		return -1;
-	    }
-
-	  if (osip_body_len > strlen (start_of_body))	/* we do not receive the */
-	    return -1;		/* complete message      */
-	  /* end_of_body = start_of_body + strlen(start_of_body); */
-	  end_of_body = start_of_body + osip_body_len;
-	  tmp = osip_malloc (end_of_body - start_of_body + 2);
-	  if (tmp == NULL)
-	    return -1;
-	  osip_strncpy (tmp, start_of_body, end_of_body - start_of_body);
-
-	  i = osip_message_set_body (sip, tmp);
-	  osip_free (tmp);
+	}
+      else if ('\n' == start_of_buf[0])
+	start_of_body = start_of_buf + 1;
+      else
+	return -1;	/* message does not end with CRLFCRLF, CRCR or LFLF */
+      
+      if (sip->content_length != NULL)
+	osip_body_len = osip_atoi (sip->content_length->value);
+      else
+	{			/* if content_length does not exist, set it. */
+	  char tmp[16];
+	  
+	  osip_body_len = strlen (start_of_body);
+	  sprintf (tmp, "%i", osip_body_len);
+	  i = osip_message_set_content_length (sip, tmp);
 	  if (i != 0)
 	    return -1;
-	  return 0;
 	}
+      
+      if (osip_body_len > strlen (start_of_body))	/* we do not receive the */
+	return -1;		/* complete message      */
+      /* end_of_body = start_of_body + strlen(start_of_body); */
+      end_of_body = start_of_body + osip_body_len;
+      tmp = osip_malloc (end_of_body - start_of_body + 2);
+      if (tmp == NULL)
+	return -1;
+      osip_strncpy (tmp, start_of_body, end_of_body - start_of_body);
+      
+      i = osip_message_set_body (sip, tmp);
+      osip_free (tmp);
+      if (i != 0)
+	return -1;
+      return 0;
     }
 
-  if (sip->content_type == NULL)
-    return -1;
-
   /* find the boundary */
   i = osip_generic_param_get_byname (sip->content_type->gen_params,
 				     "boundary", &ct_param);
@@ -733,6 +910,76 @@ msg_osip_body_parse (osip_message_t * sip, const char *start_of_buf,
   return -1;
 }
 
+/* osip_message_t *sip is filled while analysing buf */
+int
+osip_message_parse2 (osip_message_t * sip, const char *buf, size_t length)
+{
+  int i;
+  const char *next_header_index;
+  char *tmp;
+  char *beg;
+#ifdef WIN32
+  tmp = _alloca (length + 2);
+#else
+  tmp = alloca (length + 2);
+#endif
+  if (tmp==NULL)
+    {
+      OSIP_TRACE (osip_trace
+		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
+		   "Could not allocate memory.\n"));
+      return -1;
+    }
+  beg=tmp;
+  memcpy (tmp, buf, length); /* may contain binary data */
+  tmp[length]='\0';
+  osip_util_replace_all_lws (tmp);
+  /* parse request or status line */
+  i = __osip_message_startline_parse (sip, tmp, &next_header_index);
+  if (i == -1)
+    {
+      OSIP_TRACE (osip_trace
+		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
+		   "Could not parse start line of message.\n"));
+      return -1;
+    }
+  tmp = (char *) next_header_index;
+
+  /* parse headers */
+  i = msg_headers_parse (sip, tmp, &next_header_index);
+  if (i == -1)
+    {
+      OSIP_TRACE (osip_trace
+		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
+		   "error in msg_headers_parse()\n"));
+      return -1;
+    }
+  tmp = (char *) next_header_index;
+
+  /* this is a *very* simple test... (which handle most cases...) */
+  if (strlen (tmp) < 3)
+    {
+      /* this is mantory in the oSIP stack */
+      if (sip->content_length == NULL)
+	osip_message_set_content_length (sip, "0");
+      return 0;			/* no body found */
+    }
+
+  i = msg_osip_body_parse2 (sip, tmp, &next_header_index, length-(beg-tmp));
+  if (i == -1)
+    {
+      OSIP_TRACE (osip_trace
+		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
+		   "error in msg_osip_body_parse()\n"));
+      return -1;
+    }
+
+  /* this is mandatory in the oSIP stack */
+  if (sip->content_length == NULL)
+    osip_message_set_content_length (sip, "0");
+
+  return 0;
+}
 
 /* osip_message_t *sip is filled while analysing buf */
 int
