@@ -26,6 +26,27 @@
 
 extern const char *osip_protocol_version;
 
+static int strcat_simple_header (char **_string, size_t * malloc_size,
+				 char **_message, void *ptr_header,
+				 char *header_name, size_t size_of_header,
+				 int (*xxx_to_str) (void *, char **),
+				 char **next);
+static int strcat_headers_one_per_line (char **_string, size_t * malloc_size,
+					char **_message,
+					osip_list_t * headers, char *header,
+					size_t size_of_header,
+					int (*xxx_to_str) (void *, char **),
+					char **next);
+static int strcat_headers_all_on_one_line (char **_string,
+					   size_t * malloc_size,
+					   char **_message,
+					   osip_list_t * headers,
+					   char *header,
+					   size_t size_of_header,
+					   int (*xxx_to_str) (void *,
+							      char **),
+					   char **next);
+
 static int
 __osip_message_startline_to_strreq (osip_message_t * sip, char **dest)
 {
@@ -35,8 +56,7 @@ __osip_message_startline_to_strreq (osip_message_t * sip, char **dest)
   int i;
 
   *dest = NULL;
-  if ((sip == NULL) || (sip->req_uri == NULL)
-      || (sip->sip_method == NULL))
+  if ((sip == NULL) || (sip->req_uri == NULL) || (sip->sip_method == NULL))
     return -1;
 
   i = osip_uri_to_str (sip->req_uri, &rquri);
@@ -48,9 +68,8 @@ __osip_message_startline_to_strreq (osip_message_t * sip, char **dest)
   else
     sip_version = sip->sip_version;
 
-  *dest = (char *)osip_malloc(strlen (sip->sip_method)
-			      + strlen (rquri) + strlen (sip_version)
-			      + 3);
+  *dest = (char *) osip_malloc (strlen (sip->sip_method)
+				+ strlen (rquri) + strlen (sip_version) + 3);
   tmp = *dest;
   osip_strncpy (tmp, sip->sip_method, strlen (sip->sip_method));
   tmp = tmp + strlen (sip->sip_method);
@@ -83,11 +102,10 @@ __osip_message_startline_to_strresp (osip_message_t * sip, char **dest)
   else
     sip_version = sip->sip_version;
 
-  sprintf(status_code, "%u", sip->status_code);
+  sprintf (status_code, "%u", sip->status_code);
 
   *dest = (char *) osip_malloc (strlen (sip_version)
-				+ 3
-				+ strlen (sip->reason_phrase) + 4);
+				+ 3 + strlen (sip->reason_phrase) + 4);
   tmp = *dest;
 
   osip_strncpy (tmp, sip_version, strlen (sip_version));
@@ -104,7 +122,7 @@ __osip_message_startline_to_strresp (osip_message_t * sip, char **dest)
 }
 
 static int
-__osip_message_startline_to_str (osip_message_t *sip, char **dest)
+__osip_message_startline_to_str (osip_message_t * sip, char **dest)
 {
 
   if (sip->sip_method != NULL)
@@ -148,10 +166,11 @@ osip_message_get_uri (const osip_message_t * sip)
   return sip->req_uri;
 }
 
-int
-strcat_simple_header (char **_string, int *malloc_size,
+static int
+strcat_simple_header (char **_string, size_t * malloc_size,
 		      char **_message, void *ptr_header, char *header_name,
-		      int size_of_header, int (*xxx_to_str) (void *, char **),
+		      size_t size_of_header, int (*xxx_to_str) (void *,
+								char **),
 		      char **next)
 {
   char *string;
@@ -167,7 +186,7 @@ strcat_simple_header (char **_string, int *malloc_size,
       if (*malloc_size < message - string + 100 + size_of_header)
 	/* take some memory avoid to realloc too much often */
 	{			/* should not happen often */
-	  int size = message - string;
+	  size_t size = message - string;
 	  *malloc_size = message - string + size_of_header + 100;
 	  string = realloc (string, *malloc_size);
 	  if (string == NULL)
@@ -188,9 +207,9 @@ strcat_simple_header (char **_string, int *malloc_size,
 	  *next = NULL;
 	  return -1;
 	}
-      if (*malloc_size < message - string + (int) strlen (tmp) + 100)
+      if (*malloc_size < message - string + strlen (tmp) + 100)
 	{
-	  int size = message - string;
+	  size_t size = message - string;
 	  *malloc_size = message - string + strlen (tmp) + 100;
 	  string = realloc (string, *malloc_size);
 	  if (string == NULL)
@@ -213,10 +232,10 @@ strcat_simple_header (char **_string, int *malloc_size,
   return 0;
 }
 
-int
-strcat_headers_one_per_line (char **_string, int *malloc_size,
+static int
+strcat_headers_one_per_line (char **_string, size_t * malloc_size,
 			     char **_message, osip_list_t * headers,
-			     char *header, int size_of_header,
+			     char *header, size_t size_of_header,
 			     int (*xxx_to_str) (void *, char **), char **next)
 {
   char *string;
@@ -237,7 +256,7 @@ strcat_headers_one_per_line (char **_string, int *malloc_size,
       if (*malloc_size < message - string + 100 + size_of_header)
 	/* take some memory avoid to realloc too much often */
 	{			/* should not happen often */
-	  int size = message - string;
+	  size_t size = message - string;
 	  *malloc_size = message - string + size_of_header + 100;
 	  string = realloc (string, *malloc_size);
 	  if (string == NULL)
@@ -259,9 +278,9 @@ strcat_headers_one_per_line (char **_string, int *malloc_size,
 	}
       message = message + strlen (message);
 
-      if (*malloc_size < message - string + (int) strlen (tmp) + 100)
+      if (*malloc_size < message - string + strlen (tmp) + 100)
 	{
-	  int size = message - string;
+	  size_t size = message - string;
 	  *malloc_size = message - string + strlen (tmp) + 100;
 	  string = realloc (string, *malloc_size);
 	  if (string == NULL)
@@ -285,10 +304,10 @@ strcat_headers_one_per_line (char **_string, int *malloc_size,
   return 0;
 }
 
-int
-strcat_headers_all_on_one_line (char **_string, int *malloc_size,
+static int
+strcat_headers_all_on_one_line (char **_string, size_t * malloc_size,
 				char **_message, osip_list_t * headers,
-				char *header, int size_of_header,
+				char *header, size_t size_of_header,
 				int (*xxx_to_str) (void *, char **),
 				char **next)
 {
@@ -307,7 +326,7 @@ strcat_headers_all_on_one_line (char **_string, int *malloc_size,
       if (*malloc_size < message - string + 100 + size_of_header)
 	/* take some memory avoid to realloc too much often */
 	{			/* should not happen often */
-	  int size = message - string;
+	  size_t size = message - string;
 	  *malloc_size = message - string + size_of_header + 100;
 	  string = realloc (string, *malloc_size);
 	  if (string == NULL)
@@ -334,9 +353,9 @@ strcat_headers_all_on_one_line (char **_string, int *malloc_size,
 	      *next = NULL;
 	      return -1;
 	    }
-	  if (*malloc_size < message - string + (int) strlen (tmp) + 100)
+	  if (*malloc_size < message - string + strlen (tmp) + 100)
 	    {
-	      int size = message - string;
+	      size_t size = message - string;
 	      *malloc_size = message - string + (int) strlen (tmp) + 100;
 	      string = realloc (string, *malloc_size);
 	      if (string == NULL)
@@ -366,7 +385,6 @@ strcat_headers_all_on_one_line (char **_string, int *malloc_size,
   return 0;
 }
 
-#ifdef USE_TMP_BUFFER
  /* return values:
     1: structure and buffer "message" are identical.
     2: buffer "message" is not up to date with the structure info (call osip_message_to_str to update it).
@@ -379,23 +397,20 @@ osip_message_get__property (const osip_message_t * sip)
     return -1;
   return sip->message_property;
 }
-#endif
 
 int
 osip_message_force_update (osip_message_t * sip)
 {
-#ifdef USE_TMP_BUFFER
   if (sip == NULL)
     return -1;
   sip->message_property = 2;
-#endif
   return 0;
 }
 
 int
 osip_message_to_str (osip_message_t * sip, char **dest)
 {
-  int malloc_size;
+  size_t malloc_size;
   /* Added at SIPit day1 */
   char *start_of_bodies;
   char *content_length_to_modify = NULL;
@@ -408,23 +423,12 @@ osip_message_to_str (osip_message_t * sip, char **dest)
   malloc_size = SIP_MESSAGE_MAX_LENGTH;
 
   *dest = NULL;
-  if ((sip == NULL) || (sip->to == NULL)
-      || (sip->from == NULL))
+  if ((sip == NULL) || (sip->to == NULL) || (sip->from == NULL))
     return -1;
 
-#ifdef USE_TMP_BUFFER
   {
-#ifdef ENABLE_DEBUG
-    static int number_of_call = 0;
-    static int number_of_call_avoided = 0;
-
-    number_of_call++;
-#endif
     if (1 == osip_message_get__property (sip))
       {				/* message is already available in "message" */
-#ifdef ENABLE_DEBUG
-	number_of_call_avoided++;
-#endif
 
 	*dest = osip_strdup (sip->message);	/* is we just return the pointer, people will
 						   get issues while upgrading the library. This
@@ -433,11 +437,6 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 						   changed while moving to another branch
 						   developpement. replacement line will be:
 						   *dest = sip->message; */
-#ifdef ENABLE_DEBUG
-	/* if (number_of_call_avoided % 1000 == 0)
-	  printf ("number of call osip_message_to_str avoided: %i\n",
-	     number_of_call_avoided); */
-#endif
 	return 0;
 
       }
@@ -448,7 +447,6 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 	sip->message = NULL;
       }
   }
-#endif
 
   message = (char *) osip_malloc (SIP_MESSAGE_MAX_LENGTH);	/* ???? message could be > 4000  */
   *dest = message;
@@ -470,8 +468,8 @@ osip_message_to_str (osip_message_t * sip, char **dest)
   i =
     strcat_headers_one_per_line (dest, &malloc_size, &message, sip->vias,
 				 "Via: ", 5,
-				 ((int (*)(void *, char **)) &osip_via_to_str),
-				 &next);
+				 ((int (*)(void *, char **))
+				  &osip_via_to_str), &next);
   if (i != 0)
     {
       osip_free (*dest);
@@ -496,8 +494,8 @@ osip_message_to_str (osip_message_t * sip, char **dest)
   i =
     strcat_headers_one_per_line (dest, &malloc_size, &message, sip->routes,
 				 "Route: ", 7,
-				 ((int (*)(void *, char **)) &osip_route_to_str),
-				 &next);
+				 ((int (*)(void *, char **))
+				  &osip_route_to_str), &next);
   if (i != 0)
     {
       osip_free (*dest);
@@ -508,7 +506,8 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 
   i = strcat_simple_header (dest, &malloc_size, &message,
 			    sip->from, "From: ", 6,
-			    ((int (*)(void *, char **)) &osip_from_to_str), &next);
+			    ((int (*)(void *, char **)) &osip_from_to_str),
+			    &next);
   if (i != 0)
     {
       osip_free (*dest);
@@ -519,7 +518,8 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 
   i = strcat_simple_header (dest, &malloc_size, &message,
 			    sip->to, "To: ", 4,
-			    ((int (*)(void *, char **)) &osip_to_to_str), &next);
+			    ((int (*)(void *, char **)) &osip_to_to_str),
+			    &next);
   if (i != 0)
     {
       osip_free (*dest);
@@ -542,7 +542,8 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 
   i = strcat_simple_header (dest, &malloc_size, &message,
 			    sip->cseq, "CSeq: ", 6,
-			    ((int (*)(void *, char **)) &osip_cseq_to_str), &next);
+			    ((int (*)(void *, char **)) &osip_cseq_to_str),
+			    &next);
   if (i != 0)
     {
       osip_free (*dest);
@@ -554,8 +555,8 @@ osip_message_to_str (osip_message_t * sip, char **dest)
   i =
     strcat_headers_one_per_line (dest, &malloc_size, &message, sip->contacts,
 				 "Contact: ", 9,
-				 ((int (*)(void *, char **)) &osip_contact_to_str),
-				 &next);
+				 ((int (*)(void *, char **))
+				  &osip_contact_to_str), &next);
   if (i != 0)
     {
       osip_free (*dest);
@@ -617,7 +618,7 @@ osip_message_to_str (osip_message_t * sip, char **dest)
       return -1;
     }
   message = next;
-  
+
   pos = 0;
   while (!osip_list_eol (sip->headers, pos))
     {
@@ -632,9 +633,9 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 	  return -1;
 	}
 
-      if (malloc_size < message - *dest + 100 + 16 )
+      if (malloc_size < (size_t) (message - *dest + 100 + 16))
 	{
-	  int size = message - *dest;
+	  size_t size = message - *dest;
 	  malloc_size = message - *dest + 16 + 100;
 	  *dest = realloc (*dest, malloc_size);
 	  if (*dest == NULL)
@@ -666,8 +667,8 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 
   i = strcat_simple_header (dest, &malloc_size, &message,
 			    sip->content_type, "Content-Type: ", 14,
-			    ((int (*)(void *, char **)) &osip_content_type_to_str),
-			    &next);
+			    ((int (*)(void *, char **))
+			     &osip_content_type_to_str), &next);
   if (i != 0)
     {
       osip_free (*dest);
@@ -786,9 +787,9 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 
   /* we have to create the body before adding the contentlength */
   /* add enough lenght for "Content-Length: " */
-  if (malloc_size < message - *dest + 100 + 16 )
+  if (malloc_size < (size_t) (message - *dest + 100 + 16))
     {
-      int size = message - *dest;
+      size_t size = message - *dest;
       malloc_size = message - *dest + 16 + 100;
       *dest = realloc (*dest, malloc_size);
       if (*dest == NULL)
@@ -841,11 +842,9 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 
   if (osip_list_eol (sip->bodies, 0))
     {
-#ifdef USE_TMP_BUFFER
       /* same remark as at the beginning of the method */
       sip->message_property = 1;
       sip->message = osip_strdup (*dest);
-#endif
       return 0;			/* it's all done */
     }
   start_of_bodies = message;
@@ -873,10 +872,10 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 	  return -1;
 	}
 
-      if (malloc_size < message - *dest + 100 + strlen(tmp) )
+      if (malloc_size < message - *dest + 100 + strlen (tmp))
 	{
-	  int size = message - *dest;
-	  malloc_size = message - *dest + strlen(tmp) + 100;
+	  size_t size = message - *dest;
+	  malloc_size = message - *dest + strlen (tmp) + 100;
 	  *dest = realloc (*dest, malloc_size);
 	  if (*dest == NULL)
 	    return -1;
@@ -911,20 +910,16 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 
   /* we NOW have the length of bodies: */
   {
-    int size = strlen (start_of_bodies);
+    size_t size = strlen (start_of_bodies);
     char tmp[15];
 
     sprintf (tmp, "%i", size);
     /* do not use osip_strncpy here! */
-    strncpy (content_length_to_modify+5-strlen(tmp), tmp, strlen(tmp));
+    strncpy (content_length_to_modify + 5 - strlen (tmp), tmp, strlen (tmp));
   }
 
-#ifdef USE_TMP_BUFFER
   /* same remark as at the beginning of the method */
   sip->message_property = 1;
   sip->message = osip_strdup (*dest);
-#endif
   return 0;
 }
-
-
