@@ -28,6 +28,37 @@
 #define ERR_DISCARD  0		/* wrong header */
 #define WF           1		/* well formed header */
 
+static int sdp_message_parse_v (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_o (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_s (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_i (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_u (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_e (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_p (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_c (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_b (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_t (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_r (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_z (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_k (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_a (sdp_message_t * sdp, char *buf, char **next);
+static int sdp_message_parse_m (sdp_message_t * sdp, char *buf, char **next);
+
+static int sdp_append_media (char *string, int size, char *tmp,
+			     sdp_media_t * media, char **next_tmp);
+static int sdp_append_attribute (char *string, int size, char *tmp,
+				 sdp_attribute_t * attribute,
+				 char **next_tmp);
+static int sdp_append_key (char *string, int size, char *tmp, sdp_key_t * key,
+			   char **next_tmp);
+static int sdp_append_time_descr (char *string, int size, char *tmp,
+				  sdp_time_descr_t * time_descr,
+				  char **next_tmp);
+static int sdp_append_bandwidth (char *string, int size, char *tmp,
+				 sdp_bandwidth_t * bandwidth,
+				 char **next_tmp);
+static int sdp_append_connection (char *string, int size, char *tmp,
+				  sdp_connection_t * conn, char **next_tmp);
 
 int
 sdp_bandwidth_init (sdp_bandwidth_t ** b)
@@ -156,7 +187,8 @@ sdp_media_init (sdp_media_t ** media)
   (*media)->m_payloads = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*media)->m_payloads);
   (*media)->i_info = NULL;
-  (*media)->c_connections = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
+  (*media)->c_connections =
+    (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*media)->c_connections);
   (*media)->b_bandwidths = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*media)->b_bandwidths);
@@ -178,11 +210,11 @@ sdp_media_free (sdp_media_t * media)
   osip_list_ofchar_free (media->m_payloads);
   osip_free (media->i_info);
   osip_list_special_free (media->c_connections,
-		     (void *(*)(void *)) &sdp_connection_free);
+			  (void *(*)(void *)) &sdp_connection_free);
   osip_list_special_free (media->b_bandwidths,
-		     (void *(*)(void *)) &sdp_bandwidth_free);
+			  (void *(*)(void *)) &sdp_bandwidth_free);
   osip_list_special_free (media->a_attributes,
-		     (void *(*)(void *)) &sdp_attribute_free);
+			  (void *(*)(void *)) &sdp_attribute_free);
   sdp_key_free (media->k_key);
   osip_free (media);
 }
@@ -243,7 +275,7 @@ sdp_message_init (sdp_message_t ** sdp)
   return 0;
 }
 
-int
+static int
 sdp_message_parse_v (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -257,6 +289,9 @@ sdp_message_parse_v (sdp_message_t * sdp, char *buf, char **next)
   if (*equal == '\0')
     return ERR_ERROR;
 
+  if (equal == buf)
+    return ERR_DISCARD;
+  
   /* check if header is "v" */
   if (equal[-1] != 'v')
     return ERR_DISCARD;
@@ -279,8 +314,7 @@ sdp_message_parse_v (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-
-int
+static int
 sdp_message_parse_o (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -359,7 +393,7 @@ sdp_message_parse_o (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_s (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -400,7 +434,7 @@ sdp_message_parse_s (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_i (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -457,7 +491,7 @@ sdp_message_parse_i (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_u (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -496,7 +530,7 @@ sdp_message_parse_u (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_e (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -538,7 +572,7 @@ sdp_message_parse_e (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_p (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -580,7 +614,7 @@ sdp_message_parse_p (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_c (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -647,19 +681,19 @@ sdp_message_parse_c (sdp_message_t * sdp, char *buf, char **next)
 	if (slash != NULL && slash < crlf)	/* optionnal integer is there! */
 	  {
 	    i =
-	      __osip_set_next_token (&(c_header->c_addr_multicast_ttl), tmp, '/',
-			      &tmp_next);
+	      __osip_set_next_token (&(c_header->c_addr_multicast_ttl), tmp,
+				     '/', &tmp_next);
 	    if (i != 0)
 	      return -1;
 	    tmp = tmp_next;
 	    i =
-	      __osip_set_next_token (&(c_header->c_addr_multicast_int), tmp, '\r',
-			      &tmp_next);
+	      __osip_set_next_token (&(c_header->c_addr_multicast_int), tmp,
+				     '\r', &tmp_next);
 	    if (i != 0)
 	      {
 		i =
-		  __osip_set_next_token (&(c_header->c_addr_multicast_int), tmp,
-				  '\n', &tmp_next);
+		  __osip_set_next_token (&(c_header->c_addr_multicast_int),
+					 tmp, '\n', &tmp_next);
 		if (i != 0)
 		  {
 		    sdp_connection_free (c_header);
@@ -670,13 +704,13 @@ sdp_message_parse_c (sdp_message_t * sdp, char *buf, char **next)
 	else
 	  {
 	    i =
-	      __osip_set_next_token (&(c_header->c_addr_multicast_ttl), tmp, '\r',
-			      &tmp_next);
+	      __osip_set_next_token (&(c_header->c_addr_multicast_ttl), tmp,
+				     '\r', &tmp_next);
 	    if (i != 0)
 	      {
 		i =
-		  __osip_set_next_token (&(c_header->c_addr_multicast_ttl), tmp,
-				  '\n', &tmp_next);
+		  __osip_set_next_token (&(c_header->c_addr_multicast_ttl),
+					 tmp, '\n', &tmp_next);
 		if (i != 0)
 		  {
 		    sdp_connection_free (c_header);
@@ -691,7 +725,9 @@ sdp_message_parse_c (sdp_message_t * sdp, char *buf, char **next)
 	i = __osip_set_next_token (&(c_header->c_addr), tmp, '\r', &tmp_next);
 	if (i != 0)
 	  {
-	    i = __osip_set_next_token (&(c_header->c_addr), tmp, '\n', &tmp_next);
+	    i =
+	      __osip_set_next_token (&(c_header->c_addr), tmp, '\n',
+				     &tmp_next);
 	    if (i != 0)
 	      {
 		sdp_connection_free (c_header);
@@ -721,7 +757,7 @@ sdp_message_parse_c (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_b (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -767,7 +803,9 @@ sdp_message_parse_b (sdp_message_t * sdp, char *buf, char **next)
   i = __osip_set_next_token (&(b_header->b_bandwidth), tmp, '\r', &tmp_next);
   if (i != 0)
     {
-      i = __osip_set_next_token (&(b_header->b_bandwidth), tmp, '\n', &tmp_next);
+      i =
+	__osip_set_next_token (&(b_header->b_bandwidth), tmp, '\n',
+			       &tmp_next);
       if (i != 0)
 	{
 	  sdp_bandwidth_free (b_header);
@@ -796,7 +834,7 @@ sdp_message_parse_b (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_t (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -844,7 +882,9 @@ sdp_message_parse_t (sdp_message_t * sdp, char *buf, char **next)
   i = __osip_set_next_token (&(t_header->t_stop_time), tmp, '\r', &tmp_next);
   if (i != 0)
     {
-      i = __osip_set_next_token (&(t_header->t_stop_time), tmp, '\n', &tmp_next);
+      i =
+	__osip_set_next_token (&(t_header->t_stop_time), tmp, '\n',
+			       &tmp_next);
       if (i != 0)
 	{
 	  sdp_time_descr_free (t_header);
@@ -862,8 +902,7 @@ sdp_message_parse_t (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-
-int
+static int
 sdp_message_parse_r (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -912,7 +951,7 @@ sdp_message_parse_r (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_z (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -953,7 +992,7 @@ sdp_message_parse_z (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_k (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -1005,10 +1044,13 @@ sdp_message_parse_k (sdp_message_t * sdp, char *buf, char **next)
 	}
       tmp = tmp_next;
 
-      i = __osip_set_next_token (&(k_header->k_keydata), tmp, '\r', &tmp_next);
+      i =
+	__osip_set_next_token (&(k_header->k_keydata), tmp, '\r', &tmp_next);
       if (i != 0)
 	{
-	  i = __osip_set_next_token (&(k_header->k_keydata), tmp, '\n', &tmp_next);
+	  i =
+	    __osip_set_next_token (&(k_header->k_keydata), tmp, '\n',
+				   &tmp_next);
 	  if (i != 0)
 	    {
 	      sdp_key_free (k_header);
@@ -1018,10 +1060,13 @@ sdp_message_parse_k (sdp_message_t * sdp, char *buf, char **next)
     }
   else
     {
-      i = __osip_set_next_token (&(k_header->k_keytype), tmp, '\r', &tmp_next);
+      i =
+	__osip_set_next_token (&(k_header->k_keytype), tmp, '\r', &tmp_next);
       if (i != 0)
 	{
-	  i = __osip_set_next_token (&(k_header->k_keytype), tmp, '\n', &tmp_next);
+	  i =
+	    __osip_set_next_token (&(k_header->k_keytype), tmp, '\n',
+				   &tmp_next);
 	  if (i != 0)
 	    {
 	      sdp_key_free (k_header);
@@ -1051,7 +1096,7 @@ sdp_message_parse_k (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_a (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -1096,7 +1141,9 @@ sdp_message_parse_a (sdp_message_t * sdp, char *buf, char **next)
   if ((colon != NULL) && (colon < crlf))
     {
       /* att-field is alpha-numeric */
-      i = __osip_set_next_token (&(a_attribute->a_att_field), tmp, ':', &tmp_next);
+      i =
+	__osip_set_next_token (&(a_attribute->a_att_field), tmp, ':',
+			       &tmp_next);
       if (i != 0)
 	{
 	  sdp_attribute_free (a_attribute);
@@ -1104,12 +1151,14 @@ sdp_message_parse_a (sdp_message_t * sdp, char *buf, char **next)
 	}
       tmp = tmp_next;
 
-      i = __osip_set_next_token (&(a_attribute->a_att_value), tmp, '\r', &tmp_next);
+      i =
+	__osip_set_next_token (&(a_attribute->a_att_value), tmp, '\r',
+			       &tmp_next);
       if (i != 0)
 	{
 	  i =
 	    __osip_set_next_token (&(a_attribute->a_att_value), tmp, '\n',
-			    &tmp_next);
+				   &tmp_next);
 	  if (i != 0)
 	    {
 	      sdp_attribute_free (a_attribute);
@@ -1119,12 +1168,14 @@ sdp_message_parse_a (sdp_message_t * sdp, char *buf, char **next)
     }
   else
     {
-      i = __osip_set_next_token (&(a_attribute->a_att_field), tmp, '\r', &tmp_next);
+      i =
+	__osip_set_next_token (&(a_attribute->a_att_field), tmp, '\r',
+			       &tmp_next);
       if (i != 0)
 	{
 	  i =
 	    __osip_set_next_token (&(a_attribute->a_att_field), tmp, '\n',
-			    &tmp_next);
+				   &tmp_next);
 	  if (i != 0)
 	    {
 	      sdp_attribute_free (a_attribute);
@@ -1154,7 +1205,7 @@ sdp_message_parse_a (sdp_message_t * sdp, char *buf, char **next)
   return WF;
 }
 
-int
+static int
 sdp_message_parse_m (sdp_message_t * sdp, char *buf, char **next)
 {
   char *equal;
@@ -1221,7 +1272,9 @@ sdp_message_parse_m (sdp_message_t * sdp, char *buf, char **next)
 	}
       tmp = tmp_next;
 
-      i = __osip_set_next_token (&(m_header->m_number_of_port), tmp, ' ', &tmp_next);
+      i =
+	__osip_set_next_token (&(m_header->m_number_of_port), tmp, ' ',
+			       &tmp_next);
       if (i != 0)
 	{
 	  sdp_media_free (m_header);
@@ -1278,8 +1331,8 @@ sdp_message_parse_m (sdp_message_t * sdp, char *buf, char **next)
 	else
 	  more_space_before_crlf = 0;
       }
-    if (tmp_next < crlf) 
-      { /* tmp_next is still less than clrf: no space */
+    if (tmp_next < crlf)
+      {				/* tmp_next is still less than clrf: no space */
 	i = __osip_set_next_token (&str, tmp, '\r', &tmp_next);
 	if (i != 0)
 	  {
@@ -1392,7 +1445,8 @@ sdp_message_parse (sdp_message_t * sdp, const char *buf)
     }
 
   /* rfc2327: there should be at least of email or phone number! */
-  if (osip_list_size (sdp->e_emails) == 0 && osip_list_size (sdp->p_phones) == 0)
+  if (osip_list_size (sdp->e_emails) == 0
+      && osip_list_size (sdp->p_phones) == 0)
     {
       OSIP_TRACE (osip_trace
 		  (__FILE__, __LINE__, OSIP_INFO4, NULL,
@@ -1563,8 +1617,7 @@ sdp_message_parse (sdp_message_t * sdp, const char *buf)
   return 0;
 }
 
-/* internal facility */
-int
+static int
 sdp_append_connection (char *string, int size, char *tmp,
 		       sdp_connection_t * conn, char **next_tmp)
 {
@@ -1584,20 +1637,23 @@ sdp_append_connection (char *string, int size, char *tmp,
   if (conn->c_addr_multicast_ttl != NULL)
     {
       tmp = __osip_sdp_append_string (string, size, tmp, "/");
-      tmp = __osip_sdp_append_string (string, size, tmp, conn->c_addr_multicast_ttl);
+      tmp =
+	__osip_sdp_append_string (string, size, tmp,
+				  conn->c_addr_multicast_ttl);
     }
   if (conn->c_addr_multicast_int != NULL)
     {
       tmp = __osip_sdp_append_string (string, size, tmp, "/");
-      tmp = __osip_sdp_append_string (string, size, tmp, conn->c_addr_multicast_int);
+      tmp =
+	__osip_sdp_append_string (string, size, tmp,
+				  conn->c_addr_multicast_int);
     }
   tmp = __osip_sdp_append_string (string, size, tmp, CRLF);
   *next_tmp = tmp;
   return 0;
 }
 
-/* internal facility */
-int
+static int
 sdp_append_bandwidth (char *string, int size, char *tmp,
 		      sdp_bandwidth_t * bandwidth, char **next_tmp)
 {
@@ -1616,7 +1672,7 @@ sdp_append_bandwidth (char *string, int size, char *tmp,
   return 0;
 }
 
-int
+static int
 sdp_append_time_descr (char *string, int size, char *tmp,
 		       sdp_time_descr_t * time_descr, char **next_tmp)
 {
@@ -1629,7 +1685,8 @@ sdp_append_time_descr (char *string, int size, char *tmp,
 
 
   tmp = __osip_sdp_append_string (string, size, tmp, "t=");
-  tmp = __osip_sdp_append_string (string, size, tmp, time_descr->t_start_time);
+  tmp =
+    __osip_sdp_append_string (string, size, tmp, time_descr->t_start_time);
   tmp = __osip_sdp_append_string (string, size, tmp, " ");
   tmp = __osip_sdp_append_string (string, size, tmp, time_descr->t_stop_time);
 
@@ -1650,7 +1707,7 @@ sdp_append_time_descr (char *string, int size, char *tmp,
   return 0;
 }
 
-int
+static int
 sdp_append_key (char *string, int size, char *tmp, sdp_key_t * key,
 		char **next_tmp)
 {
@@ -1669,8 +1726,7 @@ sdp_append_key (char *string, int size, char *tmp, sdp_key_t * key,
   return 0;
 }
 
-/* internal facility */
-int
+static int
 sdp_append_attribute (char *string, int size, char *tmp,
 		      sdp_attribute_t * attribute, char **next_tmp)
 {
@@ -1682,7 +1738,8 @@ sdp_append_attribute (char *string, int size, char *tmp,
   if (attribute->a_att_value != NULL)
     {
       tmp = __osip_sdp_append_string (string, size, tmp, ":");
-      tmp = __osip_sdp_append_string (string, size, tmp, attribute->a_att_value);
+      tmp =
+	__osip_sdp_append_string (string, size, tmp, attribute->a_att_value);
     }
   tmp = __osip_sdp_append_string (string, size, tmp, CRLF);
 
@@ -1691,7 +1748,7 @@ sdp_append_attribute (char *string, int size, char *tmp,
 }
 
 /* internal facility */
-int
+static int
 sdp_append_media (char *string, int size, char *tmp, sdp_media_t * media,
 		  char **next_tmp)
 {
@@ -1711,7 +1768,8 @@ sdp_append_media (char *string, int size, char *tmp, sdp_media_t * media,
   if (media->m_number_of_port != NULL)
     {
       tmp = __osip_sdp_append_string (string, size, tmp, "/");
-      tmp = __osip_sdp_append_string (string, size, tmp, media->m_number_of_port);
+      tmp =
+	__osip_sdp_append_string (string, size, tmp, media->m_number_of_port);
     }
   tmp = __osip_sdp_append_string (string, size, tmp, " ");
   tmp = __osip_sdp_append_string (string, size, tmp, media->m_proto);
@@ -1954,7 +2012,8 @@ sdp_message_to_str (sdp_message_t * sdp, char **dest)
   pos = 0;
   while (!osip_list_eol (sdp->m_medias, pos))
     {
-      sdp_media_t *header = (sdp_media_t *) osip_list_get (sdp->m_medias, pos);
+      sdp_media_t *header =
+	(sdp_media_t *) osip_list_get (sdp->m_medias, pos);
       char *next_tmp;
       int i;
 
@@ -1991,15 +2050,16 @@ sdp_message_free (sdp_message_t * sdp)
   sdp_connection_free (sdp->c_connection);
 
   osip_list_special_free (sdp->b_bandwidths,
-		     (void *(*)(void *)) &sdp_bandwidth_free);
+			  (void *(*)(void *)) &sdp_bandwidth_free);
 
-  osip_list_special_free (sdp->t_descrs, (void *(*)(void *)) &sdp_time_descr_free);
+  osip_list_special_free (sdp->t_descrs,
+			  (void *(*)(void *)) &sdp_time_descr_free);
 
   osip_free (sdp->z_adjustments);
   sdp_key_free (sdp->k_key);
 
   osip_list_special_free (sdp->a_attributes,
-		     (void *(*)(void *)) &sdp_attribute_free);
+			  (void *(*)(void *)) &sdp_attribute_free);
 
   osip_list_special_free (sdp->m_medias, (void *(*)(void *)) &sdp_media_free);
 
